==> owncloud-app-contacts-2%3A1.4.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/nb_NO.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakter",
    "Address book name" : "Navn på adressebok",
    "Import" : "Importer",
    "The selected image is too big (max 1MB)" : "Det valgte bildet er for stort (maks 1MB)",
    "No contacts in here" : "Ingen kontakter her",
    "Name" : "Navn",
    "Organization" : "Organisasjon",
    "Title" : "Tittel",
    "Add field ..." : "Nytt felt ...",
    "No search result for {query}" : "Intet søkeresultat for {query}",
    "Post office box" : "Postboks",
    "Postal code" : "Postnummer",
    "City" : "By",
    "State or province" : "Stat eller fylke",
    "Country" : "Land",
    "Address" : "Adresse",
    "(new group)" : "(ny gruppe)",
    "Last name" : "Etternavn",
    "First name" : "Fornavn",
    "Additional names" : "Ev. mellomnavn",
    "Prefix" : "Prefiks",
    "Suffix" : "Suffiks",
    "All contacts" : "Alle kontakter",
    "Not grouped" : "Ikke gruppert",
    "New contact" : "Ny kontakt",
    "{addressbook} shared by {owner}" : "{addressbook} delt av {owner}",
    "No contacts in file. Only VCard files are allowed." : "Ingen kontakter i filen. Kun VCard-filer er tillatt.",
    "Nickname" : "Kallenavn",
    "Detailed name" : "Detaljert navn",
    "Notes" : "Notater",
    "Website" : "Nettsted",
    "Federated Cloud ID" : "ID for sammenknyttet sky",
    "Home" : "Hjem",
    "Work" : "Jobb",
    "Other" : "Annet",
    "Groups" : "Grupper",
    "Birthday" : "Bursdag",
    "Email" : "Epost",
    "Instant messaging" : "Direktemeldinger",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Fax" : "Faks",
    "Fax home" : "Faks hjemme",
    "Fax work" : "Faks jobb",
    "Pager" : "Pager",
    "Voice" : "Svarer",
    "Social network" : "Sosialt nettverk",
    "Settings" : "Innstillinger"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-contacts-2%3A1.5.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/nb_NO.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakter",
    "Copy Url to clipboard" : "Kopier URL til utklippstavlen",
    "Download" : "Last ned",
    "ShowURL" : "Vis URL",
    "Share Addressbook" : "Del adressebok",
    "Delete Addressbook" : "Slett adressebok",
    "Share with users or groups" : "Del med brukere eller grupper",
    "Delete" : "Slett",
    "can edit" : "kan endre",
    "Address book name" : "Navn på adressebok",
    "Import" : "Importer",
    "The selected image is too big (max 1MB)" : "Det valgte bildet er for stort (maks 1MB)",
    "No contacts in here" : "Ingen kontakter her",
    "Name" : "Navn",
    "Organization" : "Organisasjon",
    "Title" : "Tittel",
    "Add field ..." : "Nytt felt ...",
    "No search result for {query}" : "Intet søkeresultat for {query}",
    "_%n contact_::_%n contacts_" : ["%n kontakt","%n kontakter"],
    "Post office box" : "Postboks",
    "Postal code" : "Postnummer",
    "City" : "By",
    "State or province" : "Stat eller fylke",
    "Country" : "Land",
    "Address" : "Adresse",
    "(new group)" : "(ny gruppe)",
    "Last name" : "Etternavn",
    "First name" : "Fornavn",
    "Additional names" : "Ev. mellomnavn",
    "Prefix" : "Prefiks",
    "Suffix" : "Suffiks",
    "All contacts" : "Alle kontakter",
    "Not grouped" : "Ikke gruppert",
    "New contact" : "Ny kontakt",
    "{addressbook} shared by {owner}" : "{addressbook} delt av {owner}",
    "Contact could not be created." : "Klarte ikke å opprette kontakt.",
    "No contacts in file. Only VCard files are allowed." : "Ingen kontakter i filen. Kun VCard-filer er tillatt.",
    "Only VCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Bare VCard versjon 4.0 (RFC6350) eller versjon 3.0 (RFC2426) støttes.",
    "Nickname" : "Kallenavn",
    "Detailed name" : "Detaljert navn",
    "Notes" : "Notater",
    "Website" : "Nettsted",
    "Federated Cloud ID" : "ID for forent sky",
    "Home" : "Hjem",
    "Work" : "Jobb",
    "Other" : "Annet",
    "Groups" : "Grupper",
    "Birthday" : "Bursdag",
    "Anniversary" : "Jubileum",
    "Date of death" : "Dødsdato",
    "Email" : "Epost",
    "Instant messaging" : "Direktemeldinger",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Fax" : "Faks",
    "Fax home" : "Faks hjemme",
    "Fax work" : "Faks jobb",
    "Pager" : "Pager",
    "Voice" : "Svarer",
    "Social network" : "Sosialt nettverk",
    "Settings" : "Innstillinger"
},
"nplurals=2; plural=(n != 1);");
